/***************************************************************************
                    database_create_dialog.h  -  description
                             -------------------
    begin                : Sun Feb 10 2001
    copyright            : (C) 2002 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DATABASE_CREATE_DIALOG_H
#define DATABASE_CREATE_DIALOG_H

#include "prokyon.h"

#include <qdialog.h>
#include <qlineedit.h>
#include <qcombobox.h>

class Database_Create_Dialog : public QDialog {
    Q_OBJECT
public: 
	Database_Create_Dialog(QWidget *parent, const char *name=0);
	~Database_Create_Dialog();
private:
    QLineEdit *host_line, *db_line, *user_line, *pass_line, *su_line, *supass_line, *clienthost_line;
    QComboBox *comboEncoding;

private slots:
    void slot_create();
    void slot_cancel();
};

#endif
